@@ -167,6 +167,7 @@ function Request(method, url) {
   this.qsRaw = this._query; // Unused, for backwards compatibility only
   this._redirectList = [];
   this._streamRequest = false;
+  this._lookup = undefined;
   this.once('end', this.clearTimeout.bind(this));
 }
 
@@ -306,6 +307,20 @@ Request.prototype.agent = function (agent) {
   return this;
 };
 
+/**
+ * Gets/sets the `lookup` function to use custom DNS resolver.
+ *
+ * @param {Function} lookup
+ * @return {Function}
+ * @api public
+ */
+
+Request.prototype.lookup = function (lookup) {
+  if (arguments.length === 0) return this._lookup;
+  this._lookup = lookup;
+  return this;
+};
+
 /**
  * Set _Content-Type_ response header passed through `mime.getType()`.
  *
@@ -765,6 +780,7 @@ Request.prototype.request = function () {
   options.cert = this._cert;
   options.passphrase = this._passphrase;
   options.agent = this._agent;
+  options.lookup = this._lookup;
   options.rejectUnauthorized =
     typeof this._disableTLSCerts === 'boolean'
       ? !this._disableTLSCerts
@@ -783,12 +799,12 @@ Request.prototype.request = function () {
   }
 
   // initiate request
-  const mod = this._enableHttp2
+  const module_ = this._enableHttp2
     ? exports.protocols['http2:'].setProtocol(url.protocol)
     : exports.protocols[url.protocol];
 
   // request
-  this.req = mod.request(options);
+  this.req = module_.request(options);
   const { req } = this;
 
   // set tcp no delay
@@ -884,8 +900,9 @@ Request.prototype.callback = function (error, res) {
         error = new Error(message);
         error.status = res ? res.status : undefined;
       }
-    } catch (error_) {
-      error = error_;
+    } catch (err) {
+      error = err;
+      error.status = error.status || (res ? res.status : undefined);
     }
   }
 
@@ -1066,7 +1083,7 @@ Request.prototype._end = function () {
         const form = formidable();
         parser = form.parse.bind(form);
         buffer = true;
-      } else if (isImageOrVideo(mime)) {
+      } else if (isBinary(mime)) {
         parser = exports.parse.image;
         buffer = true; // For backwards-compatibility buffering default is ad-hoc MIME-dependent
       } else if (exports.parse[mime]) {
@@ -1074,7 +1091,6 @@ Request.prototype._end = function () {
       } else if (type === 'text') {
         parser = exports.parse.text;
         buffer = buffer !== false;
-
         // everyone wants their own white-labeled json
       } else if (isJSON(mime)) {
         parser = exports.parse['application/json'];
@@ -1179,7 +1195,7 @@ Request.prototype._end = function () {
     let loaded = 0;
 
     const progress = new Stream.Transform();
-    progress._transform = (chunk, encoding, cb) => {
+    progress._transform = (chunk, encoding, callback) => {
       loaded += chunk.length;
       this.emit('progress', {
         direction: 'upload',
@@ -1187,7 +1203,7 @@ Request.prototype._end = function () {
         loaded,
         total
       });
-      cb(null, chunk);
+      callback(null, chunk);
     };
 
     return progress;
@@ -1345,11 +1361,17 @@ function isText(mime) {
   return type === 'text' || subtype === 'x-www-form-urlencoded';
 }
 
-function isImageOrVideo(mime) {
-  let type = mime.split('/')[0];
-  if (type) type = type.toLowerCase().trim();
-
-  return type === 'image' || type === 'video';
+// This is not a catchall, but a start. It might be useful
+// in the long run to have file that includes all binary
+// content types from https://www.iana.org/assignments/media-types/media-types.xhtml
+function isBinary(mime) {
+  let [registry, name] = mime.split('/');
+  if (registry) registry = registry.toLowerCase().trim();
+  if (name) name = name.toLowerCase().trim();
+  return (
+    ['audio', 'font', 'image', 'video'].includes(registry) ||
+    ['gz', 'gzip'].includes(name)
+  );
 }
 
 /**
