@@ -1,6 +1,10 @@
 'use strict';
 const assert = require('assert');
-const utils = require('../../lib/utils');
+const utils =
+  process.env.OLD_NODE_TEST === '1'
+    // eslint-disable-next-line node/no-missing-require
+    ? require('../../../utils')
+    : require('../../lib/utils');
 
 describe('utils.type(str)', () => {
   it('should return the mime type', () => {
